guile-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Guile-commits] 348/437: S390: Replace s390x filenames with s390


From: Andy Wingo
Subject: [Guile-commits] 348/437: S390: Replace s390x filenames with s390
Date: Mon, 2 Jul 2018 05:14:52 -0400 (EDT)

wingo pushed a commit to branch lightning
in repository guile.

commit 192f89c0ee5114bcd287cf1a49b2acd6ad3f62c7
Author: pcpa <address@hidden>
Date:   Thu Jan 8 13:01:49 2015 -0200

    S390: Replace s390x filenames with s390
    
        * include/lightning/jit_s390.h, lib/jit_s390-cpu.c,
        lib/jit_s390-fpu.c, lib/jit_s390-sz.c, lib/jit_s390.c:
        Renamed s390x* files to s390*.
    
        * check/float.tst, check/lightning.c, configure.ac,
        include/lightning.h, include/lightning/Makefile.am,
        lib/Makefile.am, lib/jit_s390.c, lib/jit_size.c,
        lib/lightning.c: Update for renamed files.
---
 ChangeLog                                     | 11 +++++++++++
 check/float.tst                               |  2 +-
 check/lightning.c                             |  6 +++---
 configure.ac                                  |  6 +++---
 include/lightning.h                           |  2 +-
 include/lightning/Makefile.am                 |  4 ++--
 include/lightning/{jit_s390x.h => jit_s390.h} |  6 +++---
 lib/Makefile.am                               |  8 ++++----
 lib/{jit_s390x-cpu.c => jit_s390-cpu.c}       |  0
 lib/{jit_s390x-fpu.c => jit_s390-fpu.c}       |  0
 lib/{jit_s390x-sz.c => jit_s390-sz.c}         |  0
 lib/{jit_s390x.c => jit_s390.c}               |  8 ++++----
 lib/jit_size.c                                |  2 +-
 lib/lightning.c                               |  2 +-
 14 files changed, 34 insertions(+), 23 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index f293b91..780a74f 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,16 @@
 2015-01-08 Paulo Andrade <address@hidden>
 
+       * include/lightning/jit_s390.h, lib/jit_s390-cpu.c,
+       lib/jit_s390-fpu.c, lib/jit_s390-sz.c, lib/jit_s390.c:
+       Renamed s390x* files to s390*.
+
+       * check/float.tst, check/lightning.c, configure.ac,
+       include/lightning.h, include/lightning/Makefile.am,
+       lib/Makefile.am, lib/jit_s390.c, lib/jit_size.c,
+       lib/lightning.c: Update for renamed files.
+
+2015-01-08 Paulo Andrade <address@hidden>
+
         * include/lightning.h, include/lightning/jit_private.h,
         include/lightning/jit_s390x.h, lib/jit_disasm.c,
         lib/jit_s390x-cpu.c, lib/jit_s390x-fpu.c, lib/jit_s390x-sz.c,
diff --git a/check/float.tst b/check/float.tst
index ae268a9..6d463e2 100644
--- a/check/float.tst
+++ b/check/float.tst
@@ -21,7 +21,7 @@ ok:
 #else
 #  define wnan                 x80
 #endif
-#if __mips__ || __arm__ || __ppc__ || __sparc__ || __hppa__ || __aarch64__ || 
__s390x__
+#if __mips__ || __arm__ || __ppc__ || __sparc__ || __hppa__ || __aarch64__ || 
__s390__
 #  define wpinf                        x7f
 #elif __alpha__
 /* (at least) bug compatible with gcc 4.2.3 -ieee */
diff --git a/configure.ac b/configure.ac
index a36bed6..749659b 100644
--- a/configure.ac
+++ b/configure.ac
@@ -130,7 +130,7 @@ case "$target_cpu" in
     ia64)              cpu=ia64        ;;
     hppa*)             cpu=hppa        ;;
     aarch64)           cpu=aarch64     ;;
-    s390x)             cpu=s390x       ;;
+    s390*)             cpu=s390        ;;
     alpha*)            cpu=alpha       ;;
     *)                                 ;;
 esac
@@ -142,7 +142,7 @@ AM_CONDITIONAL(cpu_x86,     [test cpu-$cpu = cpu-x86])
 AM_CONDITIONAL(cpu_ia64,    [test cpu-$cpu = cpu-ia64])
 AM_CONDITIONAL(cpu_hppa,    [test cpu-$cpu = cpu-hppa])
 AM_CONDITIONAL(cpu_aarch64, [test cpu-$cpu = cpu-aarch64])
-AM_CONDITIONAL(cpu_s390x,   [test cpu-$cpu = cpu-s390x])
+AM_CONDITIONAL(cpu_s390,    [test cpu-$cpu = cpu-s390])
 AM_CONDITIONAL(cpu_alpha,   [test cpu-$cpu = cpu-alpha])
 
 # Test x87 if both, x87 and sse2 available
@@ -237,7 +237,7 @@ AM_CONDITIONAL(test_x86_x87, [test x$ac_cv_test_x86_x87 = 
xyes])
 AM_CONDITIONAL(test_arm_arm, [test x$ac_cv_test_arm_arm = xyes])
 AM_CONDITIONAL(test_arm_swf, [test x$ac_cv_test_arm_swf = xyes])
 
-AM_CONDITIONAL(test_nodata, [test cpu-$cpu = cpu-mips -o cpu-$cpu = cpu-ppc -o 
cpu-$cpu = cpu-sparc -o cpu-$cpu = cpu-x86 -o cpu-$cpu = cpu-ia64 -o cpu-$cpu = 
cpu-hppa -o cpu-$cpu = cpu-s390x -o cpu-$cpu = cpu-alpha])
+AM_CONDITIONAL(test_nodata, [test cpu-$cpu = cpu-mips -o cpu-$cpu = cpu-ppc -o 
cpu-$cpu = cpu-sparc -o cpu-$cpu = cpu-x86 -o cpu-$cpu = cpu-ia64 -o cpu-$cpu = 
cpu-hppa -o cpu-$cpu = cpu-s390 -o cpu-$cpu = cpu-alpha])
 
 if test $cpu = arm; then
      AC_CHECK_LIB(m, sqrtf, ,
diff --git a/include/lightning.h b/include/lightning.h
index 6cdd360..0e8f365 100644
--- a/include/lightning.h
+++ b/include/lightning.h
@@ -141,7 +141,7 @@ typedef jit_int32_t         jit_fpr_t;
 #elif defined(__aarch64__)
 #  include <lightning/jit_aarch64.h>
 #elif defined(__s390__) || defined(__s390x__)
-#  include <lightning/jit_s390x.h>
+#  include <lightning/jit_s390.h>
 #elif defined(__alpha__)
 #  include <lightning/jit_alpha.h>
 #endif
diff --git a/include/lightning/Makefile.am b/include/lightning/Makefile.am
index 5e3fef3..84342ec 100644
--- a/include/lightning/Makefile.am
+++ b/include/lightning/Makefile.am
@@ -51,9 +51,9 @@ if cpu_aarch64
 lightning_include_HEADERS =    \
        jit_aarch64.h
 endif
-if cpu_s390x
+if cpu_s390
 lightning_include_HEADERS =    \
-       jit_s390x.h
+       jit_s390.h
 endif
 if cpu_alpha
 lightning_include_HEADERS =    \
diff --git a/include/lightning/jit_s390x.h b/include/lightning/jit_s390.h
similarity index 96%
rename from include/lightning/jit_s390x.h
rename to include/lightning/jit_s390.h
index 196a02f..905f4be 100644
--- a/include/lightning/jit_s390x.h
+++ b/include/lightning/jit_s390.h
@@ -17,8 +17,8 @@
  *     Paulo Cesar Pereira de Andrade
  */
 
-#ifndef _jit_s390x_h
-#define _jit_s390x_h
+#ifndef _jit_s390_h
+#define _jit_s390_h
 
 #define JIT_HASH_CONSTS                1
 #define JIT_NUM_OPERANDS       2
@@ -71,4 +71,4 @@ typedef enum {
 #define JIT_NOREG              _NOREG
 } jit_reg_t;
 
-#endif /* _jit_s390x_h */
+#endif /* _jit_s390_h */
diff --git a/lib/Makefile.am b/lib/Makefile.am
index 3bd7cb7..1283575 100644
--- a/lib/Makefile.am
+++ b/lib/Makefile.am
@@ -62,10 +62,10 @@ EXTRA_DIST =                        \
        jit_ppc-cpu.c           \
        jit_ppc-fpu.c           \
        jit_ppc-sz.c            \
-       jit_s390x.c             \
-       jit_s390x-cpu.c         \
-       jit_s390x-fpu.c         \
-       jit_s390x-sz.c          \
+       jit_s390.c              \
+       jit_s390-cpu.c          \
+       jit_s390-fpu.c          \
+       jit_s390-sz.c           \
        jit_sparc.c             \
        jit_sparc-cpu.c         \
        jit_sparc-fpu.c         \
diff --git a/lib/jit_s390x-cpu.c b/lib/jit_s390-cpu.c
similarity index 100%
rename from lib/jit_s390x-cpu.c
rename to lib/jit_s390-cpu.c
diff --git a/lib/jit_s390x-fpu.c b/lib/jit_s390-fpu.c
similarity index 100%
rename from lib/jit_s390x-fpu.c
rename to lib/jit_s390-fpu.c
diff --git a/lib/jit_s390x-sz.c b/lib/jit_s390-sz.c
similarity index 100%
rename from lib/jit_s390x-sz.c
rename to lib/jit_s390-sz.c
diff --git a/lib/jit_s390x.c b/lib/jit_s390.c
similarity index 99%
rename from lib/jit_s390x.c
rename to lib/jit_s390.c
index 3e45078..d3d3f06 100644
--- a/lib/jit_s390x.c
+++ b/lib/jit_s390.c
@@ -45,8 +45,8 @@ static void _patch(jit_state_t*,jit_word_t,jit_node_t*);
 extern void __clear_cache(void *, void *);
 
 #define PROTO                          1
-#  include "jit_s390x-cpu.c"
-#  include "jit_s390x-fpu.c"
+#  include "jit_s390-cpu.c"
+#  include "jit_s390-fpu.c"
 #undef PROTO
 
 /*
@@ -1205,8 +1205,8 @@ _emit_code(jit_state_t *_jit)
 }
 
 #define CODE                           1
-#  include "jit_s390x-cpu.c"
-#  include "jit_s390x-fpu.c"
+#  include "jit_s390-cpu.c"
+#  include "jit_s390-fpu.c"
 #undef CODE
 
 void
diff --git a/lib/jit_size.c b/lib/jit_size.c
index 522e3b6..ae4c633 100644
--- a/lib/jit_size.c
+++ b/lib/jit_size.c
@@ -47,7 +47,7 @@ static jit_int16_t    _szs[jit_code_last_code + 1] = {
 #  elif defined(__aarch64__)
 #    include "jit_aarch64-sz.c"
 #  elif defined(__s390__) || defined(__s390x__)
-#    include "jit_s390x-sz.c"
+#    include "jit_s390-sz.c"
 #  elif defined(__alpha__)
 #    include "jit_alpha-sz.c"
 #  endif
diff --git a/lib/lightning.c b/lib/lightning.c
index 2795720..b9173b7 100644
--- a/lib/lightning.c
+++ b/lib/lightning.c
@@ -3186,7 +3186,7 @@ _patch_register(jit_state_t *_jit, jit_node_t *node, 
jit_node_t *link,
 #elif defined(__aarch64__)
 #  include "jit_aarch64.c"
 #elif defined(__s390__) || defined(__s390x__)
-#  include "jit_s390x.c"
+#  include "jit_s390.c"
 #elif defined(__alpha__)
 #  include "jit_alpha.c"
 #endif



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/check/lightning.c b/check/lightning.c
index e33008e..81b2671 100644
--- a/check/lightning.c
+++ b/check/lightning.c
@@ -1914,7 +1914,7 @@ get_float(skip_t skip)
 static float
 make_float(double d)
 {
     /* This is an workaround to a bug in Hercules s390x emulator,
      * and at least HP-UX ia64 not have these */
 #if defined(HAVE_ISNAN) && defined(HAVE_ISINF)
     if (isnan(d))      return ( 0.0f/0.0f);
@@ -4194,10 +4194,10 @@ main(int argc, char *argv[])
                          sizeof(cmdline) - opt_short,
                          " -D__aarch64__=1");
 #endif
-#if defined(__s390x__)
+#if defined(__s390__) || defined(__s390x__)
     opt_short += snprintf(cmdline + opt_short,
                          sizeof(cmdline) - opt_short,
-                         " -D__s390x__=1");
+                         " -D__s390__=1");
 #endif
 #if defined(__alpha__)
     opt_short += snprintf(cmdline + opt_short,
@@ -1914,7 +1914,7 @@ get_float(skip_t skip)
 make_float(double d)
 {
-    /* This is an workaround to a bug in Hercules s390x emulator,
+    /* This is an workaround to a bug in Hercules s390 emulator,
      * and at least HP-UX ia64 not have these */
 #if defined(HAVE_ISNAN) && defined(HAVE_ISINF)